package cn.com.infosec.x509;

import cn.com.infosec.util.Selector;
import cn.com.infosec.util.Store;
import java.security.cert.CertSelector;
import java.security.cert.CertStore;
import java.security.cert.PKIXParameters;
import java.security.cert.TrustAnchor;
import java.security.cert.X509CertSelector;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;

public class ExtendedPKIXParameters extends PKIXParameters {
   public static final int PKIX_VALIDITY_MODEL = 0;
   public static final int CHAIN_VALIDITY_MODEL = 1;
   private List stores;
   private Selector selector;
   private boolean additionalLocationsEnabled;
   private List additionalStores;
   private Set trustedACIssuers;
   private Set necessaryACAttributes;
   private Set prohibitedACAttributes;
   private Set attrCertCheckers;
   private int validityModel;
   private boolean useDeltas;

   public ExtendedPKIXParameters(Set trustAnchors) {
      ExtendedPKIXParameters var10000 = this;
      ExtendedPKIXParameters var10001 = this;
      ExtendedPKIXParameters var10002 = this;
      ExtendedPKIXParameters var10003 = this;
      ExtendedPKIXParameters var10004 = this;
      ExtendedPKIXParameters var10005 = this;
      super(trustAnchors);
      this.validityModel = 0;
      this.useDeltas = true;
      ArrayList var2;
      var2 = new ArrayList.<init>();
      var10005.stores = var2;
      var2 = new ArrayList.<init>();
      var10004.additionalStores = var2;
      HashSet var3;
      var3 = new HashSet.<init>();
      var10003.trustedACIssuers = var3;
      var3 = new HashSet.<init>();
      var10002.necessaryACAttributes = var3;
      var3 = new HashSet.<init>();
      var10001.prohibitedACAttributes = var3;
      var3 = new HashSet.<init>();
      var10000.attrCertCheckers = var3;
   }

   public static ExtendedPKIXParameters getInstance(PKIXParameters param0) {
      // $FF: Couldn't be decompiled
   }

   protected void setParams(PKIXParameters params) {
      ExtendedPKIXParameters var10001 = this;
      PKIXParameters var10002 = params;
      this.setDate(params.getDate());
      this.setCertPathCheckers(params.getCertPathCheckers());
      this.setCertStores(params.getCertStores());
      this.setAnyPolicyInhibited(params.isAnyPolicyInhibited());
      this.setExplicitPolicyRequired(params.isExplicitPolicyRequired());
      this.setPolicyMappingInhibited(params.isPolicyMappingInhibited());
      this.setRevocationEnabled(params.isRevocationEnabled());
      this.setInitialPolicies(params.getInitialPolicies());
      this.setPolicyQualifiersRejected(params.getPolicyQualifiersRejected());
      this.setSigProvider(params.getSigProvider());
      this.setTargetCertConstraints(params.getTargetCertConstraints());

      try {
         var10001.setTrustAnchors(var10002.getTrustAnchors());
      } catch (Exception var3) {
         throw new RuntimeException(var3.getMessage());
      }

      if (params instanceof ExtendedPKIXParameters) {
         ExtendedPKIXParameters params1;
         ExtendedPKIXParameters var10000 = params1 = (ExtendedPKIXParameters)params;
         this.validityModel = params1.validityModel;
         this.useDeltas = params1.useDeltas;
         this.additionalLocationsEnabled = params1.additionalLocationsEnabled;
         Selector var2;
         if ((var2 = var10000.selector) == null) {
            var2 = null;
         } else {
            var2 = (Selector)var2.clone();
         }

         this.selector = var2;
         this.stores = new ArrayList(params1.stores);
         this.additionalStores = new ArrayList(params1.additionalStores);
         this.trustedACIssuers = new HashSet(params1.trustedACIssuers);
         this.prohibitedACAttributes = new HashSet(params1.prohibitedACAttributes);
         this.necessaryACAttributes = new HashSet(params1.necessaryACAttributes);
         this.attrCertCheckers = new HashSet(params1.attrCertCheckers);
      }

   }

   public boolean isUseDeltasEnabled() {
      return this.useDeltas;
   }

   public void setUseDeltasEnabled(boolean useDeltas) {
      this.useDeltas = useDeltas;
   }

   public int getValidityModel() {
      return this.validityModel;
   }

   public void setCertStores(List stores) {
      if (stores != null) {
         Iterator stores1 = stores.iterator();

         while(stores1.hasNext()) {
            this.addCertStore((CertStore)stores1.next());
         }
      }

   }

   public void setStores(List stores) {
      ExtendedPKIXParameters var10000;
      ArrayList var3;
      if (stores == null) {
         var10000 = this;
         var3 = new ArrayList.<init>();
         var10000.stores = var3;
      } else {
         Iterator var2 = stores.iterator();

         while(var2.hasNext()) {
            if (!(var2.next() instanceof Store)) {
               throw new ClassCastException("All elements of list must be of type cn.com.infosec.util.Store.");
            }
         }

         var10000 = this;
         var3 = new ArrayList.<init>(stores);
         var10000.stores = var3;
      }

   }

   public void addStore(Store store) {
      List var2;
      if ((var2 = this.stores) != null) {
         var2.add(store);
      }

   }

   public void addAddionalStore(Store store) {
      if (store != null) {
         this.additionalStores.add(store);
      }

   }

   public List getAdditionalStores() {
      return Collections.unmodifiableList(this.additionalStores);
   }

   public List getStores() {
      return Collections.unmodifiableList(new ArrayList(this.stores));
   }

   public void setValidityModel(int validityModel) {
      this.validityModel = validityModel;
   }

   public Object clone() {
      // $FF: Couldn't be decompiled
   }

   public boolean isAdditionalLocationsEnabled() {
      return this.additionalLocationsEnabled;
   }

   public void setAdditionalLocationsEnabled(boolean enabled) {
      this.additionalLocationsEnabled = enabled;
   }

   public Selector getTargetConstraints() {
      Selector var1;
      return (var1 = this.selector) != null ? (Selector)var1.clone() : null;
   }

   public void setTargetConstraints(Selector selector) {
      if (selector != null) {
         this.selector = (Selector)selector.clone();
      } else {
         this.selector = null;
      }

   }

   public void setTargetCertConstraints(CertSelector selector) {
      super.setTargetCertConstraints(selector);
      if (selector != null) {
         this.selector = X509CertStoreSelector.getInstance((X509CertSelector)selector);
      } else {
         this.selector = null;
      }

   }

   public Set getTrustedACIssuers() {
      return Collections.unmodifiableSet(this.trustedACIssuers);
   }

   public void setTrustedACIssuers(Set trustedACIssuers) {
      if (trustedACIssuers == null) {
         trustedACIssuers.clear();
      } else {
         Iterator var2 = trustedACIssuers.iterator();

         while(var2.hasNext()) {
            if (!(var2.next() instanceof TrustAnchor)) {
               throw new ClassCastException("All elements of set must be of type " + TrustAnchor.class.getName() + ".");
            }
         }

         this.trustedACIssuers.clear();
         this.trustedACIssuers.addAll(trustedACIssuers);
      }
   }

   public Set getNecessaryACAttributes() {
      return Collections.unmodifiableSet(this.necessaryACAttributes);
   }

   public void setNecessaryACAttributes(Set necessaryACAttributes) {
      if (necessaryACAttributes == null) {
         this.necessaryACAttributes.clear();
      } else {
         Iterator var2 = necessaryACAttributes.iterator();

         while(var2.hasNext()) {
            if (!(var2.next() instanceof String)) {
               throw new ClassCastException("All elements of set must be of type String.");
            }
         }

         this.necessaryACAttributes.clear();
         this.necessaryACAttributes.addAll(necessaryACAttributes);
      }
   }

   public Set getProhibitedACAttributes() {
      return this.prohibitedACAttributes;
   }

   public void setProhibitedACAttributes(Set prohibitedACAttributes) {
      if (prohibitedACAttributes == null) {
         this.prohibitedACAttributes.clear();
      } else {
         Iterator var2 = prohibitedACAttributes.iterator();

         while(var2.hasNext()) {
            if (!(var2.next() instanceof String)) {
               throw new ClassCastException("All elements of set must be of type String.");
            }
         }

         this.prohibitedACAttributes.clear();
         this.prohibitedACAttributes.addAll(prohibitedACAttributes);
      }
   }

   public Set getAttrCertCheckers() {
      return Collections.unmodifiableSet(this.attrCertCheckers);
   }

   public void setAttrCertCheckers(Set attrCertCheckers) {
      if (attrCertCheckers == null) {
         this.attrCertCheckers.clear();
      } else {
         Iterator var2 = attrCertCheckers.iterator();

         while(var2.hasNext()) {
            if (!(var2.next() instanceof PKIXAttrCertChecker)) {
               throw new ClassCastException("All elements of set must be of type " + PKIXAttrCertChecker.class.getName() + ".");
            }
         }

         this.attrCertCheckers.clear();
         this.attrCertCheckers.addAll(attrCertCheckers);
      }
   }
}
